# SudaPy Documentation

Welcome to SudaPy -- a Sudan-focused Python toolkit for Geomatics.

## Getting Started

- [Installation](installation.md)
- [Quickstart](quickstart.md)
- [CLI Reference](cli.md)

## API Reference

- [CRS Registry](api/crs.md)
- [Vector Operations](api/vector.md)
- [Raster Operations](api/raster.md)
- [Visualization](api/viz.md)

<!-- Arabic placeholder / عنصر نائب للغة العربية
## البدء السريع
سيتم إضافة التوثيق باللغة العربية في إصدار مستقبلي.
-->
